Task: LIGHT-Dialogue
=====================
Description: LIGHT is a text adventure game with actions and dialogue collected.The source data is collected between crowdworkers playing the game.

Link: http://parl.ai/projects/light

Tags: #LIGHT-Dialogue, #All, #Grounded

